<?php
/*
 Plugin Name: Gold Addons for Elementor
 Plugin URI: https://goldaddons.com/
 Description: Gold Addons plugin extends elementor widgets with many new & fresh widgets.
 Version: 1.1.5
 Author: GoldAddons
 Author URI: https://goldaddons.com/pricing/
 License: GPLv3
 Text Domain: gold-addons-for-elementor
*/

namespace GoldAddons;

// Exit if accessed directly.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * GoldAddons_For_Elementor
 *
 * @since 1.0.0
 */
final class Plugin {

    /**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 * @var string The plugin version.
	 */
	const VERSION = '1.1.5';

    /**
     * Plugin Development
     *
     * @since 1.0.0
     * @var string The plugin development mode.
     */
    const DEVELOPMENT = false;

    /**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

    /**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '5.6';

    /**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var GoldAddons_For_Elementor The single instance of the class.
	 */
	private static $_instance = null;

    /**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @access public
	 * @static
	 * @return GoldAddons_For_Elementor An instance of the class.
	 */
    public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

    /**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
    public function __construct() {

        if( self::DEVELOPMENT ) {
            $this->version = esc_attr( uniqid() );
        } else {
            $this->version = self::VERSION;
        }

		add_action( 'init', [ $this, 'i18n' ] );
		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}

    /**
	 * Load Textdomain
	 *
	 * Load plugin localization files.
	 * Fired by `init` action hook.
	 *
	 * @since 1.0.0
	 * @access public
	 */
    public function i18n() {

		load_plugin_textdomain( 'gold-addons-for-elementor' );

	}

	/**
	 * Define constants.
	 * 
	 * @since 1.1.5
	 * @access private
	 */
	private function constants() {
        if ( ! defined( 'GOLDADDONS_VERSION' ) ) {
            define( 'GOLDADDONS_VERSION', $this->version );
        }
        if ( ! defined( 'GOLDADDONS_BASENAME' ) ) {
            define( 'GOLDADDONS_BASENAME', plugin_basename( __FILE__ ) );
        }
        if ( ! defined( 'GOLDADDONS_DIR' ) ) {
            define( 'GOLDADDONS_DIR', plugin_dir_path( __FILE__ ) );
        }
        if ( ! defined( 'GOLDADDONS_URI' ) ) {
            define( 'GOLDADDONS_URI', plugin_dir_url( __FILE__ ) );
        }
		if ( ! defined( 'GOLDADDONS_CSS_URI' ) ) {
			define( 'GOLDADDONS_CSS_URI', plugins_url( 'assets/css', __FILE__ ) );
		}
		if ( ! defined( 'GOLDADDONS_WIDGETS_URI' ) ) {
			define( 'GOLDADDONS_WIDGETS_URI', plugins_url( 'assets/widgets', __FILE__ ) );
		}
		if ( ! defined( 'GOLDADDONS_VENDOR_URI' ) ) {
			define( 'GOLDADDONS_VENDOR_URI', plugins_url( 'assets/vendor', __FILE__ ) );
		}
	}

    /**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 * @access public
	 */
    public function init() {
        // Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}

        $this->constants();

		// Include the helper class.
		require_once( __DIR__ . '/includes/class-helper.php' );

        // Include admin.php file.
        if( is_admin() ) {
            require_once( __DIR__ . '/includes/admin/class-admin.php' );
        }

        // Include functions.php file.
        require_once( __DIR__ . '/includes/functions.php' );

        // Editor style
        add_action( 'elementor/editor/after_enqueue_styles', [ $this, 'editor_style' ] );

        // Register Widget Styles
        add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'register_widget_styles' ] );

        // Register Widget Scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'register_widget_scripts' ] );

		// Register Widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );
		//add_action( 'elementor/controls/controls_registered', [ $this, 'init_controls' ] );
    }

    /**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 * @access public
	 */
    public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'gold-addons-for-elementor' ),
			'<strong>' . esc_html__( 'GoldAddons Plugin', 'gold-addons-for-elementor' ) . '</strong>',
			'<a href="'. admin_url() .'plugin-install.php?tab=plugin-information&plugin=elementor&TB_iframe=true&width=772&height=624" class="thickbox open-plugin-details-modal"><strong>' . esc_html__( 'Elementor Plugin', 'gold-addons-for-elementor' ) . '</strong></a>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

    /**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 * @access public
	 */
    public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'gold-addons-for-elementor' ),
			'<strong>' . esc_html__( 'GoldAddons Plugin', 'gold-addons-for-elementor' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'gold-addons-for-elementor' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

    /**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'gold-addons-for-elementor' ),
			'<strong>' . esc_html__( 'GoldAddons Plugin', 'gold-addons-for-elementor' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'gold-addons-for-elementor' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

    /**
     * Register Editor Style
     *
     * Include editor styling file.
     *
     * @since 1.0.0
     * @access public
     */
    public function editor_style() {

		wp_enqueue_style( 'goldaddons-icons', plugins_url( 'assets/css/icons.min.css', __FILE__ ), [], $this->version );
        wp_enqueue_style( 'goldaddons-editor', plugins_url( 'assets/css/editor.css', __FILE__ ), [], $this->version );

    }

    /**
     * Register Widgets Styles
     *
     * Include widgets styling files.
     *
     * @since 1.0.0
     * @access public
     */
    public function register_widget_styles() {
		// General
		wp_register_style( 'goldaddons-icons', 			GOLDADDONS_CSS_URI . '/icons.min.css', [], $this->version );
		wp_register_style( 'goldaddons-general', 		GOLDADDONS_CSS_URI . '/general.min.css', [], $this->version );

		// Vendor
		wp_register_style( 'goldaddons-magnific-popup', GOLDADDONS_VENDOR_URI . '/magnific-popup/magnific-popup.min.css', [], $this->version );
		wp_register_style( 'goldaddons-owl-carousel', 	GOLDADDONS_VENDOR_URI . '/owl-carousel/owl-carousel.min.css', [], $this->version );

		// Free widgets.
		wp_register_style( 'goldaddons-alert', 			GOLDADDONS_WIDGETS_URI . '/alert/alert.min.css', [], $this->version );
		wp_register_style( 'goldaddons-button', 		GOLDADDONS_WIDGETS_URI . '/button/button.min.css', [], $this->version );
		wp_register_style( 'goldaddons-blog', 			GOLDADDONS_WIDGETS_URI . '/blog/blog.min.css', [], $this->version );
		wp_register_style( 'goldaddons-contact-form-7', GOLDADDONS_WIDGETS_URI . '/contact-form-7/contact-form-7.min.css', [], $this->version );
		wp_register_style( 'goldaddons-modal', 			GOLDADDONS_WIDGETS_URI . '/modal/modal.min.css', [], $this->version );
		wp_register_style( 'goldaddons-popover', 		GOLDADDONS_WIDGETS_URI . '/popover/popover.min.css', [], $this->version );
		wp_register_style( 'goldaddons-price-box', 		GOLDADDONS_WIDGETS_URI . '/price-box/price-box.min.css', [], $this->version );
		wp_register_style( 'goldaddons-team', 			GOLDADDONS_WIDGETS_URI . '/team/team.min.css', [], $this->version );
		wp_register_style( 'goldaddons-tooltip', 		GOLDADDONS_WIDGETS_URI . '/tooltip/tooltip.min.css', [], $this->version );

		// Pro widgets.
		wp_register_style( 'goldaddons-3d-flip-box', 	GOLDADDONS_WIDGETS_URI . '/3d-flip-box/3d-flip-box.min.css', [], $this->version );
		wp_register_style( 'goldaddons-accordion', 		GOLDADDONS_WIDGETS_URI . '/accordion/accordion.min.css', [], $this->version );
		wp_register_style( 'goldaddons-portfolio', 		GOLDADDONS_WIDGETS_URI . '/portfolio/portfolio.min.css', [], $this->version );
	}

    /**
     * Register Widgets Scripts
     *
     * Include widgets scripts files.
     *
     * @since 1.0.0
     * @access public
     */
    public function register_widget_scripts() {
		// Vendor
		wp_register_script( 'goldaddons-popper', 				GOLDADDONS_VENDOR_URI . '/popper/popper.min.js', [ 'jquery' ], $this->version );
		wp_register_script( 'goldaddons-bootstrap', 			GOLDADDONS_VENDOR_URI . '/bootstrap/bootstrap.min.js', [ 'goldaddons-popper', 'jquery' ], $this->version );
		wp_register_script( 'goldaddons-infinite-scroll', 		GOLDADDONS_VENDOR_URI . '/infinite-scroll/infinite-scroll.min.js', [ 'jquery' ], $this->version );
		wp_register_script( 'goldaddons-magnific-popup', 		GOLDADDONS_VENDOR_URI . '/magnific-popup/magnific-popup.min.js', [ 'jquery' ], $this->version );
		wp_register_script( 'goldaddons-magnific-popup-init', 	GOLDADDONS_VENDOR_URI . '/magnific-popup/magnific-popup-init.min.js', [], $this->version );
		wp_register_script( 'goldaddons-owl-carousel', 			GOLDADDONS_VENDOR_URI . '/owl-carousel/owl-carousel.min.js', [ 'jquery' ], $this->version );
		wp_register_script( 'goldaddons-owl-carousel-init',		GOLDADDONS_VENDOR_URI . '/owl-carousel/owl-carousel-init.min.js', [], $this->version );

		// Free widgets.
		wp_register_script( 'goldaddons-alert', 				GOLDADDONS_WIDGETS_URI . '/alert/alert.min.js', [], $this->version );
		wp_register_script( 'goldaddons-blog', 					GOLDADDONS_WIDGETS_URI . '/blog/blog.min.js', [], $this->version );
		wp_register_script( 'goldaddons-image-carousel', 		GOLDADDONS_WIDGETS_URI . '/image-carousel/image-carousel.min.js', [], $this->version );
		wp_register_script( 'goldaddons-modal', 				GOLDADDONS_WIDGETS_URI . '/modal/modal.min.js', [], $this->version );
		wp_register_script( 'goldaddons-team', 					GOLDADDONS_WIDGETS_URI . '/team/team.min.js', [], $this->version );

		// Pro widgets.
		wp_register_script( 'goldaddons-portfolio', 			GOLDADDONS_WIDGETS_URI . '/portfolio/portfolio.min.js', [], $this->version );
	}

    /**
	 * Init Widgets
	 *
	 * Include widgets files and register them.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function init_widgets() {
      $widgets = wp_normalize_path( GOLDADDONS_DIR . '/widgets/*.php' );
      foreach( glob( $widgets ) as $widget ) {
          $class_name = basename( $widget, '.php' );
          $class_name = str_replace( '-', ' ', $class_name );
          $class_name = ucwords( $class_name );
          $class_name = str_replace( ' ', '_', $class_name );
          $class_name = '\GoldAddons\Widget\\' . $class_name;

          require_once( $widget );

          \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new $class_name );
      }
	}

    /**
	 * Init Controls
	 *
	 * Include controls files and register them
	 *
	 * @since 1.0.0
	 * @access public
	 */
    public function init_controls() {}

}

Plugin::instance();

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
