<?php
/**
 * Ajax
 *
 * The GoldAddons plugin ajax class.
 *
 * @package GoldAddons for Elementor
 * @since 1.0.8
 */

namespace GoldAddons;

// Direct access not allowed.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Ajax {
    
    /**
     * API URL
     *
     * @since 1.0.8
     * @access private
     * @return string
     */
    private $url = 'https://goldaddons.com/wp-admin/admin-ajax.php';
    
    /**
     * Store Code
     *
     * @since 1.0.8
     * @access private
     * @return string
     */
    private $store = '4Cdj75YXAXZ38l2';
    
    /**
	 * Instance
	 *
	 * Single instance of this object.
	 *
	 * @since 1.0.8
	 * @access public
	 * @var null|object
	 */
	public static $instance = null;

	/**
	 * Get Instance
	 *
	 * Access the single instance of this class.
	 *
	 * @since 1.0.8
	 * @access public
	 * @return object
	 */
	public static function get_instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
    
    /**
     * Class Constructor
     */
    function __construct() {
        
        add_action( 'wp_ajax_activate', [ $this, 'activate' ] );
        
    }
    
    /**
     * Activate
     *
     * Register and activate the GoldAddons plugin with license key.
     *
     * @since 1.0.8
     * @access public
     * @return array
     */
    function activate() {
        
        $sku = isset( $_POST['sku'] ) ? $_POST['sku'] : '';
        $key = isset( $_POST['key'] ) ? $_POST['key'] : '';
        
        $params = add_query_arg(
            [
                'action'        => 'license_key_activate',
                'store_code'    => esc_attr( $this->store ),
                'sku'           => esc_attr( $sku ),
                'license_key'   => esc_attr( $key ),
                'domain'        => esc_url( $_SERVER['SERVER_NAME'] )
            ], $this->url
        );
        
        /**
         * Do not allow multiple activation 
         * instances for current domain.
         *
         * Deactivate already activated key before activating new one.
         */
        $this->deactivate();
        
        /**
         * Activate license key.
         */
        $this->response( $sku, $license, $params );
        
        wp_die();
    }
    
    /**
     * Response
     *
     * The GoldAddons.com server API response.
     *
     * @param string $sku     (required) The product SKU.
     * @param string $license (required) The license key.
     * @param array  $params  (required) The API parameters.
     *
     * @since 1.0.8
     * @access public
     * @return array
     */
    public function response( $sku, $license, $params ) {
        $response   = wp_remote_get( $params );
        $json       = json_decode( wp_remote_retrieve_body( $response ), true ); // array()
        $error      = isset( $json['error'] ) ? esc_attr( $json['error'] ) : ''; // true | false
        $data       = isset( $json['data'] ) ? $json['data'] : ''; // array()
        
        if( $error ) {
            foreach( $json['errors'] as $key => $value ) {
                $license['message'] = $value[0];
            }
        } else { // If there is not errors.
            if( ! $error ) {
                $license['sku']             = isset( $sku ) ? esc_attr( $sku ) : '';
                $license['key']             = isset( $data['the_key'] ) ? esc_attr( $data['the_key'] ) : '';
                $license['activation_id']   = isset( $data['activation_id'] ) ? esc_attr( $data['activation_id'] ) : '';
                $license['message']         = isset( $json['message'] ) ? esc_html( $json['message'] ) : '';
                $license['status']          = isset( $data['status'] ) ? esc_attr( $data['status'] ) : '';
            }
        }
        
        update_option( '_goldaddons_license', serialize( $license ) );
        
        echo json_encode( $json );
    }
    
    /**
     * Validate
     *
     * Validate the GoldAddons license key.
     *
     * @param string $license (required) The license key.
     *
     * @since 1.0.8
     * @access public
     * @return array
     */
    public function validate( $license ) {
        $aid = unserialize( get_option( '_goldaddons_license' ) );
        
        if( $aid ) {
            $aid = $aid['activation_id'];
        }
        
        $params = add_query_arg(
            array(
                'action'        => 'license_key_validate',
                'store_code'    => esc_attr( $this->store ),
                'sku'           => esc_attr( $license['sku'] ),
                'license_key'   => esc_attr( $license['key'] ),
                'activation_id' => esc_attr( $aid ),
                'domain'        => esc_url( $_SERVER['SERVER_NAME'] )
            ), $this->url
        );
        
        $response   = wp_remote_get( $params );
        $json       = json_decode( wp_remote_retrieve_body( $response ), true );
        $data       = $json['data'];
        
        return $data;
    }
    
    /**
     * Deactivate
     *
     * Deactivate the GoldAddons license key.
     *
     * @since 1.0.8
     * @access public
     * @return array
     */
    public function deactivate() {
        $option = unserialize( get_option( '_goldaddons_license' ) );
        
        $sku = isset( $option['sku'] ) ? $option['sku'] : '';
        $key = isset( $option['key'] ) ? $option['key'] : '';
        $activation_id = isset( $option['activation_id'] ) ? $option['activation_id'] : '';
        
        if( ! empty( $activation_id ) ) {
            $params = add_query_arg(
                array(
                    'action'        => 'license_key_deactivate',
                    'store_code'    => esc_attr( $this->store ),
                    'sku'           => esc_attr( $sku ),
                    'license_key'   => esc_attr( $key ),
                    'domain'        => esc_url( $_SERVER['SERVER_NAME'] ),
                    'activation_id' => esc_attr( $activation_id )
                ), $this->url
            );
            
           $response = wp_remote_get( $params );
        }
    }
    
}

Ajax::get_instance();
