<?php

/**
 * The plugin update class.
 *
 * @link       https://goldaddons.com
 * @since      1.1.4
 *
 * @package    Gold Addons for Elementor
 */

namespace GoldAddons;

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Fired during update check.
 *
 * This class defines all code necessary to update the plugin.
 *
 * @since      1.1.4
 * @package    Gold Addons for Elementor
 * @author     Gold Addons <support@goldaddons.com>
 */
class Update {
    
    /**
     * The API URL.
     *
     * Gold Addons API URL.
     *
     * @since 1.1.4
     * @access private
     * @return string
     */
    private $api_url = 'https://www.update.goldaddons.com/';
    
    /**
     * The license status.
     *
     * @since   1.1.4
     * @access  private
     * @var     bool        $license     The status of the license.
     */
    private $license;
    
    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.1.4
     * @param    bool      $license        The status of the license.
	 */
    function __construct( $license ) {
        if ( is_admin() ) {
        
            $this->license = $license;
            
            if ( 'active' == $this->license['status'] ) {
                
                // The plugin info.
                add_filter( 'plugins_api', [ $this, 'plugin_info' ], 20, 3 );
                
                // The push update.
                add_filter( 'site_transient_update_plugins', [ $this, 'push_update' ] );

                // Cache the results.
                add_action( 'upgrader_process_complete', [ $this, 'after_update' ], 10, 2 );
                
            }
            
        }
    }
    
    /**
     * Plugin Information
     *
     * Get plugin information from JSON file located on remote Gold Addons server.
     *
     * @param $res Contains information for plugins with custom update server.
     * @param $action (string) The type of the action.
     * @param $args (object) ( [slug] => woocommerce [is_ssl] => [fields] => Array ( [banners] => 1 [reviews] => 1 [downloaded] => [active_installs] => 1 ) [per_page] => 24 [locale] => en_US )
     *
     * @since 1.1.4
     * @access public
     * @return array
     */
    public function plugin_info( $res, $action, $args ) {
        
        // Added by Jerry
        if( ! $action ) {
            $action = 'plugin_information';
        }
        
        // do nothing if this is not about getting plugin information
        if( $action !== 'plugin_information' ) {
           return false;
        }
        
        // do nothing if it is not our plugin	
        if( 'gold-addons-pro-for-elementor' !== $args->slug ) {
            return $res;
        }
        
        // trying to get from cache first.
        if( false == $remote = get_transient( 'upgrade_gold_addons_pro' ) ) {
 
            // info.json is the file with the actual plugin information on your server
            $remote = wp_remote_get( esc_url( $this->api_url . 'get-info.php?slug=gold-addons-pro-for-elementor&action=info' ), [
                'timeout' => 10,
                'headers' => [
                    'Accept' => 'application/json'
                ] 
            ] );
 
            if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
                set_transient( 'upgrade_gold_addons_pro', $remote, 43200 ); // 12 hours cache
            }
 
        }
        
        if( $remote ) {
 
            $remote = json_decode( $remote['body'] );
            $res = new \stdClass();
            $res->name = esc_html( $remote->name );
            $res->slug = esc_attr( $remote->slug );
            $res->version = esc_attr( $remote->version );
            $res->tested = esc_attr( $remote->tested );
            $res->requires = esc_attr( $remote->requires );
            $res->author = esc_html( $remote->author );
            $res->author_profile = esc_url( $remote->author_homepage ); // WordPress.org profile
            $res->donate_link = esc_url( $remote->donate_link );
            $res->requires_php = esc_attr( $remote->requires_php );
            $res->download_link = esc_url( $remote->download_link );
            $res->trunk = esc_url( $remote->download_link );
            $res->last_updated = esc_attr( $remote->last_updated );
            $res->sections = [
                'description' => $remote->sections->description,
                'installation' => $remote->sections->installation,
                'changelog' => $remote->sections->changelog,
                // you can add your custom sections (tabs) here 
            ];
 
            // in case you want the screenshots tab, use the following HTML format for its content:
            // <ol><li><a href="IMG_URL" target="_blank" rel="noopener noreferrer"><img src="IMG_URL" alt="CAPTION" /></a><p>CAPTION</p></li></ol>
            if( ! empty( $remote->sections->screenshots ) ) {
                $res->sections['screenshots'] = $remote->sections->screenshots;
            }
 
            $res->banners = [
                'low'  => esc_url( $remote->banners->low ),
                'high' => esc_url( $remote->banners->high )
            ];
            
            return $res;
        }
 
        return false;
        
    }
    
    /**
     * Push Update
     *
     * Push the update information into WP transients.
     *
     * @param $transient (string) The holder of transient details.
     *
     * @since 1.1.4
     * @access public
     */
    public function push_update( $transient ) {
        if ( empty( $transient->checked ) ) {
            return $transient;
        }
        
        $path       = wp_normalize_path( WP_PLUGIN_DIR . '/gold-addons-pro-for-elementor/' . 'gold-addons-pro-for-elementor.php' );
        $plugin     = get_plugin_data( $path );
        $version    = $plugin['Version'];
        
        // trying to get from cache first.
        if( false == $remote = get_transient( 'upgrade_gold_addons_pro' ) ) {
            
            // info.json is the file with the actual plugin information on your server
            $remote = wp_remote_get( esc_url( $this->api_url . 'get-info.php?slug=gold-addons-pro-for-elementor&action=update' ), [
                'timeout' => 10,
                'headers' => [
                    'Accept' => 'application/json'
                ]
            ] );
            
            if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
                set_transient( 'upgrade_agama_pro', $remote, 43200 ); // 12 hours cache
            }
            
        }
        
        if( $remote && ! is_wp_error( $remote ) ) {
            
            $remote = json_decode( $remote['body'] );
            
            if( $remote && version_compare( $version, $remote->version, '<' ) ) {
                $res = new \stdClass();
                $res->slug = esc_attr( $remote->slug );
                $res->plugin = esc_attr( 'gold-addons-pro-for-elementor/gold-addons-pro-for-elementor.php' );
                $res->new_version = esc_attr( $remote->version );
                $res->tested = esc_attr( $remote->tested );
                $res->package = esc_url( $remote->download_link );
                $res->icons = [
                    'default' => esc_url( $remote->icons->default )
                ];
           		$transient->response[$res->plugin] = $res;
           		//$transient->checked[$res->plugin] = $remote->version;
           	}
 
        }
        
        return $transient;
    }
    
    /**
     * After Update
     *
     * Clean the cache when new plugin version is installed.
     *
     * @param $upgrader_object (object) The upgrader object.
     * @param $options (array) The options holder.
     *
     * @since 1.1.4
     * @access public
     * @return bool | null
     */
    public function after_update( $upgrader_object, $options ) {
        if ( $options['action'] == 'update' && $options['type'] === 'plugin' )  {
            // just clean the cache when new plugin version is installed
            delete_transient( 'upgrade_gold_addons_pro' );
        }
    }
    
}
